drop _all
clear
capture clear matrix
set mem 500m
set more off

global input 	= "H:\KE Education\KE-WEB\INPUT"		// 	Folder where raw data is stored	
global output 	= "H:\KE Education\KE-WEB\OUTPUT"		//	Folder where all modified data files are saved

tempfile kihbs kihbs_hh wms wms_hh

*Goal here is to create a pooled, repeated cross-section of households from the 1997 WMS and 2006 KIHBS.
*Will save 2 files at the end: a child level file, and household level aggregates.
*Child data is comparable for both surveys and can be used for analysis of enrolment.
*Aggregated household data will need to be used for expenditure analysis.
*Expenditure is available by child or household in KIHBS, and by household for prim, sec, & tertiary spending in WMS.
*So the strategy is to use KIHBS child data and sum up for each level of education, to match the 3 categories in WMS.

*KNBS CPI annual weighted average index:
*1997: 99.90
*2006: 206.7

**************
*** KIHBS ****
**************

***	Begin with original, raw, KIHBS files converted from SPSS to STATA in StatTransfer
use 	"$input/Section B Household member Information.dta", clear							
mmerge 	id_clust id_hh b_id using "$input/Section C education.dta", unmatched(none)
mmerge 	id_clust id_hh 		using "$input/Section A identification.dta", unmatched(none)
mmerge 	id_clust id_hh 		using "$input/consumption aggregated data.dta", unmatched(none)

	drop	_merge
	rename 	b04 sex
	rename 	b05a age
	rename 	y_i exp_food

***	Opting to use the child-level expenditure data, which will be aggregated up to match the WMS
***	Reason being that this is the only way we can disentangle primary, sec., and tertiary spending
	rename 	c19a exp_fees
	rename 	c19b exp_books
	rename 	c19c exp_uniform
	rename 	c19d exp_board
	rename 	c19e exp_transport
	rename 	c19f exp_maintenance
	rename 	c19g exp_extra
	rename 	c19h exp_exam
	rename 	c19i exp_pta
	rename 	c19j exp_pocket
	rename 	c19k exp_other
	egen 	exp_edtotal = rsum(exp_fees exp_books exp_uniform exp_board exp_transport exp_maint exp_extra exp_exam exp_pta exp_pocket exp_other)

	gen 	enrol = c10 ==1
	rename 	c12 grade
	replace grade = 15 if grade>15 & grade<22
	replace grade = 99 if grade>21
	gen 	enrolP = grade>0 & grade<=8
	gen 	enrolS = grade>8 & grade<=14
	gen 	enrolU = grade==15
	rename 	id_clust ea
	rename 	id_hh hh
	rename 	b_id i
	gen 	literate=c24==2|c24==3|c24==4
	gen 	public = c13==1|c13==5|c13==9
	gen 	private = public==0

***	Need to separate fees into different variables for primary, secondary and tertiary in preparation for collapse
	foreach var in fees books uniform board transport maintenance extra exam pta pocket other edtotal{
		gen exp_`var'P = exp_`var' if enrolP==1
		gen exp_`var'S = exp_`var' if enrolS==1
		gen exp_`var'U = exp_`var' if enrolU==1
	}
***	Ditto for public vs private enrolment
	foreach g in P S U{ 
		gen public`g' = public==1 & enrol`g'==1
		gen private`g' = private==1 & enrol`g'==1
	}
	drop 	if age==0
	tab 	age, g(agedum)
	tab 	grade, g(gradedum)

	forval g = 1/8{
		gen ner`g' = grade==`g' & age==(`g'+5)
		replace ner`g'=. if age!=(`g'+5)
	}

***	Education of HH head***
	gen 	educ=c04a 
	replace educ=0 if c04a==20
	replace educ=. if c04a==21
	replace educ=. if c04a==25
	replace educ=. if c03==2
	replace educ=15 if c04a==16|c04a==17|c04a==18|c04a==19
	replace educ=0 if c03==2
	replace educ=. if b03!=1
	bysort 	prov district ea hh: egen hhh_educ = mean(educ)

	gen 	year = 1
	keep 	year prov district ea hh i sex ner* age  exp* enrol* grade* public* private* weight* agedum6-agedum16 hhh_*
	order 	year prov district ea hh i sex ner* age* exp* enrol* grade* public* private* weight*
	sort 	ea hh i
	tostring _all, replace force

save `kihbs', replace

***	Collapse command adds up TOTAL expenditure and total number of kids enrolled per household
	destring 	_all, replace
	keep 		if age>5 & age<21
	collapse (mean) weight_hh weight_pop pubshare=public ner* (firstnm) hhh_educ (sum) exp_fees* exp_books* exp_uniform* exp_board* exp_transport* ///
	exp_food exp_edtotal* gradedum* enrol enrolP enrolS enrolU agedum6-agedum16 public* private*, by(prov district ea hh)
	tostring _all, replace force
	gen year = 1
	
save `kihbs_hh', replace


************
*** WMS ****
************

***	Switch to original, raw 1997 WMS survey files 
use 	"$input/Fin-cor1.dta", clear
merge 	cluster hhnumber using "$input/Fin-exp1.dta"

	rename 	food exp_food
	rename 	pfeesy exp_feesP
	rename 	pbssy exp_booksP
	rename 	puscy exp_uniformP
	rename 	ptray exp_transportP
	rename 	pfoody exp_boardP
	rename 	pharay exp_harambeeP

	rename 	sfeesy exp_feesS
	rename 	sbssy exp_booksS
	rename 	suscy exp_uniformS
	rename 	sstray exp_transportS
	rename 	sfoody exp_boardS
	rename 	sharay exp_harambeeS

	rename 	psfesy exp_feesU
	rename 	psbssy exp_booksU
	rename 	psuscy exp_uniformU
	rename 	pstray exp_transportU
	rename 	psfody exp_boardU

	egen 	exp_edtotalP = rsum(exp_feesP exp_booksP exp_uniformP exp_transportP exp_boardP exp_harambeeP)
	egen 	exp_edtotalS = rsum(exp_feesS exp_booksS exp_uniformS exp_transportS exp_boardS exp_harambeeS)
	egen 	exp_edtotalU = rsum(exp_feesU exp_booksU exp_uniformU exp_transportU exp_boardU)

	rename otedcy exp_other
	foreach var in fees books uniform transport board edtotal{
		egen exp_`var' = rsum(exp_`var'P exp_`var'S exp_`var'U)
	}
	egen exp_harambee = rsum(exp_harambeeP exp_harambeeS)

	gen 	enrol	= cuatsh==1
	gen 	public 	= tyofsch==1
	gen 	private = public==0
	rename 	cluster ea
	rename 	hhnumber hh
	rename 	serial i
	rename 	province prov
	rename 	weight weight_hh
	gen 	literate= canrewte==1

	gen 	grade 	= hilevre
	replace grade 	= 20 if grade==21
	replace grade 	= 99 if grade==22
	replace grade 	= grade - 1 if grade>7
	replace grade 	= grade - 1 if grade>8
	replace grade 	= grade - 1 if grade>10
	replace grade 	= grade - 1 if grade>12
	replace grade 	= grade - 1 if grade>14
	replace grade 	= 99 if grade==94
	replace grade 	= 99 if enrol==0
	gen 	enrolP 	= grade>0 & grade<=8
	gen 	enrolS 	= grade>8 & grade<=14
	gen 	enrolU 	= grade==15

***	Separate out public and private enrolment by education level
	foreach g in P S U{ 
		gen public`g' = public==1 & enrol`g'==1
		gen private`g' = private==1 & enrol`g'==1
	}

	drop if age==0
	tab age, g(agedum)
	tab grade, g(gradedum)

	forval g = 1/8{
		gen ner`g' = grade==`g' & age==(`g'+5)
		replace ner`g'=. if age!=(`g'+5)
	}

***	Education of HH Head****
	gen 	educ = hilevre
	replace educ = 7 if hilevre==8 
	replace educ = 8 if hilevre==9 | hilevre==10
	replace educ = 9 if hilevre==11
	replace educ = 10 if hilevre==12 | hilevre==13
	replace educ = 11 if hilevre==14
	replace educ = 12 if hilevre==15 | hilevre==16
	replace educ = 13 if hilevre==17
	replace educ = 14 if hilevre==18 | hilevre==19
	replace educ = 15 if hilevre==20 | hilevre==21
	replace educ = . if hilevre==22 | hilevre==99
	replace educ = 0 if everatsc==2
	replace educ = . if relation!=1
	bysort 	prov district ea hh: egen hhh_educ = mean(educ)

	gen 	year = 0
	keep 	year prov district ea hh i sex age ner* exp* enrol* grade* public* private* literate weight_hh agedum6-agedum16 hhh_*
	order 	year prov district ea hh i sex age ner* exp* enrol* grade* public* private* literate weight_hh
	sort 	ea hh i
	tostring _all, replace force

save `wms', replace

	destring 	_all, replace
	keep 		if age>5 & age<21
	collapse 	(mean) weight_hh pubshare=public exp_fees* exp_books* exp_unif* exp_board* exp_transp* exp_food exp_edtotal* ner* (firstnm) hhh_educ ///
				(sum) gradedum* enrol enrolP enrolS enrolU agedum6-agedum16 public* private*, by(prov district ea hh)
	tostring 	_all, replace force
	gen 		year = 0

save `wms_hh', replace


************************
*** Merge the pieces ***
************************

***	HH level
append using `kihbs_hh'
	destring _all, replace
	foreach var in exp_fees exp_books exp_uniform exp_board exp_transport exp_edtotal{
		gen `var'97 = `var'
		replace `var'97 = `var'/2.07 if year==1
		foreach g in P S U{
			gen `var'`g'97 = `var'`g'
			replace `var'`g'97 = `var'`g'/2.07 if year==1
	}
	}
	gen exp_food97 = exp_food
	replace exp_food97 = exp_food/2.07 if year==1

save "$output/enrol_pooled_hh.dta", replace 


***Individual level
use 			`wms', clear
append 	using 	`kihbs'
	qui destring _all, replace
	foreach var in exp_fees exp_books exp_uniform exp_board exp_transport exp_edtotal{
		gen `var'97 = `var'
		replace `var'97 = `var'/2.07 if year==1
		foreach g in P S U{
			gen `var'`g'97 = `var'`g'
			replace `var'`g'97 = `var'`g'/2.07 if year==1
	}
	}
	gen 	exp_food97 = exp_food
	replace exp_food97 = exp_food/2.07 if year==1
	sort 	prov district ea hh

save "$output/enrol_pooled.dta", replace

exit



